@@ -1,4 +1,4 @@
-package Pcore::DBH::DDL::pgsql;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::DBH::DDL::pgsql;
 
 use Pcore -class;
 
